@@ -26,6 +26,8 @@ class FileHeader:
     def __init__(self):
         self.Machine = 0x8664
 
+# A Dummy class to represent a PE.
+
 
 class PE:
     def __init__(self, sections=None, optional_header=None):
@@ -33,6 +35,9 @@ class PE:
         self.OPTIONAL_HEADER = optional_header
         self.FILE_HEADER = FileHeader()
 
+    def merge_modified_section_data(self):
+        pass
+
 
 class TestImageValidationInterface(unittest.TestCase):
 
